@@ -1,3 +1,6 @@
+#[cfg(feature = "serialize")]
+mod serialize;
+
 use cidr_utils::cidr::IpCidr;
 use std::collections::{hash_set::IntoIter, HashSet};
 use std::net::IpAddr;
@@ -85,12 +88,12 @@ pub struct NoProxy {
     has_wildcard: bool,
 }
 
-impl<T: AsRef<str>> From<T> for NoProxy {
-    fn from(value: T) -> Self {
-        let content: HashSet<_> = value
-            .as_ref()
-            .split(',')
-            .map(|item| NoProxyItem::from(item.trim().to_string()))
+impl NoProxy {
+    fn from_iterator<V: AsRef<str>, I: Iterator<Item = V>>(iterator: I) -> Self {
+        let content: HashSet<_> = iterator
+            .map(|item| item.as_ref().trim().to_string())
+            .filter(|item| !item.is_empty())
+            .map(NoProxyItem::from)
             .collect();
         let has_wildcard = content.contains(&NoProxyItem::Wildcard);
         Self {
@@ -100,6 +103,24 @@ impl<T: AsRef<str>> From<T> for NoProxy {
     }
 }
 
+impl From<&str> for NoProxy {
+    fn from(value: &str) -> Self {
+        Self::from_iterator(value.split(','))
+    }
+}
+
+impl From<String> for NoProxy {
+    fn from(value: String) -> Self {
+        Self::from_iterator(value.split(','))
+    }
+}
+
+impl From<Vec<String>> for NoProxy {
+    fn from(value: Vec<String>) -> Self {
+        Self::from_iterator(value.iter())
+    }
+}
+
 impl IntoIterator for NoProxy {
     type Item = NoProxyItem;
     type IntoIter = IntoIter<NoProxyItem>;
@@ -117,6 +138,10 @@ impl Extend<NoProxyItem> for NoProxy {
 }
 
 impl NoProxy {
+    pub fn is_empty(&self) -> bool {
+        self.content.is_empty()
+    }
+
     pub fn matches(&self, input: &str) -> bool {
         if self.has_wildcard {
             return true;
@@ -140,26 +165,6 @@ impl ToString for NoProxy {
     }
 }
 
-#[cfg(feature = "serialize")]
-impl serde::Serialize for NoProxy {
-    fn serialize<S>(&self, serializer: S) -> Result<S::Ok, S::Error>
-    where
-        S: serde::Serializer,
-    {
-        serializer.serialize_str(&self.to_string())
-    }
-}
-
-#[cfg(feature = "serialize")]
-impl<'de> serde::Deserialize<'de> for NoProxy {
-    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
-    where
-        D: serde::Deserializer<'de>,
-    {
-        String::deserialize(deserializer).map(Self::from)
-    }
-}
-
 #[cfg(test)]
 mod tests {
     use super::*;
@@ -184,6 +189,12 @@ mod tests {
         );
     }
 
+    #[test]
+    fn filter_empty() {
+        let no_proxy = NoProxy::from("");
+        assert!(no_proxy.is_empty());
+    }
+
     #[test]
     fn wildcard() {
         should_match("*", "www.wikipedia.org");
@@ -217,6 +228,12 @@ mod tests {
         shouldnt_match("192.168.0.", "192.169.0.1");
     }
 
+    #[test]
+    fn white_space() {
+        shouldnt_match("", "localhost");
+        shouldnt_match("", "somewhere.local");
+    }
+
     #[test]
     fn combination() {
         let pattern = "127.0.0.1,localhost,.local,169.254.169.254,fileshare.company.com";
@@ -249,13 +266,4 @@ mod tests {
         first.extend(second);
         assert!(first.has_wildcard);
     }
-
-    #[cfg(feature = "serialize")]
-    #[test]
-    fn serialization() {
-        let proxy = NoProxy::from("foo.bar,1.2.3.4");
-        let json = serde_json::to_string(&proxy).unwrap();
-        let result: NoProxy = serde_json::from_str(&json).unwrap();
-        assert_eq!(proxy, result);
-    }
 }
